@@ -2,7 +2,7 @@
  *
  *  Connection Manager
  *
- *  Copyright (C) 2007-2009  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2007-2010  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -203,7 +203,6 @@ static void powered_changed(struct connman_device *device)
 static int set_powered(struct connman_device *device, connman_bool_t powered)
 {
 	struct connman_device_driver *driver = device->driver;
-	enum connman_service_type type;
 	int err;
 
 	DBG("device %p powered %d", device, powered);
@@ -214,15 +213,13 @@ static int set_powered(struct connman_device *device, connman_bool_t powered)
 	if (!driver)
 		return -EINVAL;
 
-	type = __connman_device_get_service_type(device);
-
 	if (powered == TRUE) {
 		if (driver->enable) {
 			device->powered_pending = powered;
 
 			err = driver->enable(device);
 			if (err == 0)
-				__connman_notifier_enable(type);
+				__connman_technology_enable_device(device);
 		} else
 			err = -EINVAL;
 	} else {
@@ -237,7 +234,7 @@ static int set_powered(struct connman_device *device, connman_bool_t powered)
 		if (driver->disable) {
 			err = driver->disable(device);
 			if (err == 0)
-				__connman_notifier_disable(type);
+				__connman_technology_disable_device(device);
 		} else
 			err = -EINVAL;
 	}
@@ -478,13 +475,6 @@ static GDBusSignalTable device_signals[] = {
 	{ },
 };
 
-static void emit_devices_signal(void)
-{
-	connman_dbus_property_changed_array(CONNMAN_MANAGER_PATH,
-			CONNMAN_MANAGER_INTERFACE, "Devices",
-			DBUS_TYPE_OBJECT_PATH, __connman_device_list, NULL);
-}
-
 static int register_interface(struct connman_element *element)
 {
 	struct connman_device *device = element->device;
@@ -501,8 +491,6 @@ static int register_interface(struct connman_element *element)
 
 	device->registered = TRUE;
 
-	emit_devices_signal();
-
 	return 0;
 }
 
@@ -514,15 +502,12 @@ static void unregister_interface(struct connman_element *element)
 
 	device->registered = FALSE;
 
-	emit_devices_signal();
-
 	g_dbus_unregister_interface(connection, element->path,
 						CONNMAN_DEVICE_INTERFACE);
 }
 
 static int setup_device(struct connman_device *device)
 {
-	enum connman_service_type type;
 	int err;
 
 	DBG("device %p", device);
@@ -535,8 +520,7 @@ static int setup_device(struct connman_device *device)
 		return err;
 	}
 
-	type = __connman_device_get_service_type(device);
-	__connman_notifier_register(type);
+	__connman_technology_add_device(device);
 
 	switch (device->mode) {
 	case CONNMAN_DEVICE_MODE_UNKNOWN:
@@ -545,6 +529,9 @@ static int setup_device(struct connman_device *device)
 		break;
 	}
 
+	if (__connman_udev_get_blocked(device->phyindex) == TRUE)
+		return 0;
+
 	if (device->offlinemode == FALSE &&
 				device->powered_persistent == TRUE)
 		__connman_device_enable(device);
@@ -577,8 +564,6 @@ static void probe_driver(struct connman_element *element, gpointer user_data)
 
 static void remove_device(struct connman_device *device)
 {
-	enum connman_service_type type;
-
 	DBG("device %p", device);
 
 	__connman_device_disable(device);
@@ -590,8 +575,7 @@ static void remove_device(struct connman_device *device)
 		break;
 	}
 
-	type = __connman_device_get_service_type(device);
-	__connman_notifier_unregister(type);
+	__connman_technology_remove_device(device);
 
 	unregister_interface(&device->element);
 
@@ -971,8 +955,6 @@ enum connman_device_mode connman_device_get_mode(struct connman_device *device)
 int connman_device_set_powered(struct connman_device *device,
 						connman_bool_t powered)
 {
-	enum connman_service_type type;
-
 	DBG("driver %p powered %d", device, powered);
 
 	if (device->timeout > 0) {
@@ -994,12 +976,10 @@ int connman_device_set_powered(struct connman_device *device,
 	device->powered = powered;
 	device->powered_pending = powered;
 
-	type = __connman_device_get_service_type(device);
-
 	if (device->powered == TRUE)
-		__connman_notifier_enable(type);
+		__connman_technology_enable_device(device);
 	else
-		__connman_notifier_disable(type);
+		__connman_technology_disable_device(device);
 
 	if (device->registered == FALSE)
 		return 0;
@@ -1054,7 +1034,6 @@ int __connman_device_scan(struct connman_device *device)
 
 int __connman_device_enable(struct connman_device *device)
 {
-	enum connman_service_type type;
 	int err;
 
 	DBG("device %p", device);
@@ -1073,8 +1052,7 @@ int __connman_device_enable(struct connman_device *device)
 
 	device->powered = TRUE;
 
-	type = __connman_device_get_service_type(device);
-	__connman_notifier_enable(type);
+	__connman_technology_enable_device(device);
 
 	return 0;
 }
@@ -1092,7 +1070,6 @@ int __connman_device_enable_persistent(struct connman_device *device)
 
 int __connman_device_disable(struct connman_device *device)
 {
-	enum connman_service_type type;
 	int err;
 
 	DBG("device %p", device);
@@ -1120,8 +1097,7 @@ int __connman_device_disable(struct connman_device *device)
 
 	device->powered = FALSE;
 
-	type = __connman_device_get_service_type(device);
-	__connman_notifier_disable(type);
+	__connman_technology_disable_device(device);
 
 	return 0;
 }
